pub struct PromoteReplicaRequest {
pub peer_instance: Option<String>,
}Expand description
PromoteReplicaRequest promotes a Filestore standby instance (replica).
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
peer_instance: Option<String>Optional. The resource name of the peer instance to promote, in the format projects/{project_id}/locations/{location_id}/instances/{instance_id}. The peer instance is required if the operation is called on an active instance.