pub struct ReplicaConfig {
pub last_active_sync_time: Option<DateTime<Utc>>,
pub peer_instance: Option<String>,
pub state: Option<String>,
pub state_reasons: Option<Vec<String>>,
pub state_update_time: Option<DateTime<Utc>>,
}Expand description
Replica configuration for the instance.
This type is not used in any activity, and only used as part of another schema.
Fields
last_active_sync_time: Option<DateTime<Utc>>Output only. The timestamp of the latest replication snapshot taken on the active instance and is already replicated safely.
peer_instance: Option<String>Optional. The name of the source instance for the replica, in the format projects/{project}/locations/{location}/instances/{instance}. This field is required when creating a replica.
state: Option<String>Output only. The replica state.
state_reasons: Option<Vec<String>>Output only. Additional information about the replication state, if available.
state_update_time: Option<DateTime<Utc>>Output only. The time when the replica state was updated.