[−][src]Struct google_file1::Instance
A Cloud Filestore instance.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations instances create projects (request)
- locations instances patch projects (request)
- locations instances get projects (response)
Fields
name: Option<String>Output only. The resource name of the instance, in the format projects/{project}/locations/{location}/instances/{instance}.
labels: Option<HashMap<String, String>>Resource labels to represent user provided metadata.
create_time: Option<String>Output only. The time when the instance was created.
state: Option<String>Output only. The instance state.
etag: Option<String>Server-specified ETag for the instance resource to prevent simultaneous updates from overwriting each other.
File system shares on the instance. For this version, only a single file share is supported.
tier: Option<String>The service tier of the instance.
networks: Option<Vec<NetworkConfig>>VPC networks to which the instance is connected. For this version, only a single network is supported.
status_message: Option<String>Output only. Additional information about the instance state, if available.
description: Option<String>The description of the instance (2048 characters or less).